#
# spec file
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-sphinxcontrib-apidoc%{psuffix}
Version:        0.5.0
Release:        1.4
Summary:        A Sphinx extension for running 'sphinx-apidoc' on each build
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            http://www.sphinx-doc.org/
Source:         https://files.pythonhosted.org/packages/source/s/sphinxcontrib-apidoc/sphinxcontrib-apidoc-%{version}.tar.gz
BuildRequires:  %{python_module pbr >= 4.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Sphinx >= 5.0.0
Requires:       python-pbr
BuildArch:      noarch
# SECTION test requirements
%if %{with test}
BuildRequires:  %{python_module pytest >= 3.0}
BuildRequires:  %{python_module sphinxcontrib-apidoc = %{version}}
%endif
# /SECTION
%python_subpackages

%description
*sphinx-apidoc* is a tool for automatic generation of Sphinx sources that,
using the `autodoc <sphinx_autodoc>`_ extension, documents a whole package in
the style of other automatic API documentation tools. *sphinx-apidoc* does not
actually build documentation - rather it simply generates it. As a result, it
must be run before *sphinx-build*.

%prep
%autosetup -p1 -n sphinxcontrib-apidoc-%{version}

%build
%python_build

%install
%if !%{with test}
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
%pytest tests
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE
%doc AUTHORS ChangeLog README.rst
%{python_sitelib}/*
%endif

%changelog
* Sun Jan 21 2024 Dirk Müller <dmueller@suse.com>
- update to 0.5.0:
  * Added quote marks to indicate default template dir is a
    string
  * Removed more white space to match required style
  * Removed white space screwing with PR linter
  * Added description of apidoc\_template\_dir option to README
  * Added missed line in patch for templates support
  * Added support for autodoc --templatedir option
  * Use release/v1 branch of pypi release workflow
* Thu Oct  5 2023 Dirk Müller <dmueller@suse.com>
- update to 0.4.0:
  * Remove docs build
  * Fix lint issues
  * Configure trusted publishing
  * Migrate to Python 3-style type annotations
  * Bump sphinx minimum
  * Remove pytest upper cap
  * Migrate to pre-commit
  * Drop Python < 3.8 support
  * Migrate from Travis to GitHub Actions
  * tests: Handle Sphinx < 7.2
  * fix tests with Sphinx 7.2
  * README: Fix typo
  * travis: Update PyPI password
- drop sphinx72.patch (upstream)
* Wed Aug 30 2023 Markéta Machová <mmachova@suse.com>
- add sphinx72.patch to fix tests, sent upstream
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Fri Apr 26 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.3.0
  * Ensure '--tocfile' isn't configured for Sphinx < 1.8
  * Support more configuration options
  * fix the dist name used to get the version after installation
- Launching tests using multibuild. It just did not work without it.
* Fri Dec  7 2018 Matej Cepl <mcepl@suse.com>
- Remove wrong BR on python-sphinxcontrib
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Apr 16 2018 tbechtold@suse.com
- Initial packaging (version 0.2.1)
